==> qt6-qtbase-6.3.1p0.tgz: lib/cmake/Qt6CoreTools/Qt6CoreToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::moc" for configuration "Release"
set_property(TARGET Qt6::moc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::moc PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/moc"
  )

list(APPEND _cmake_import_check_targets Qt6::moc )
list(APPEND _cmake_import_check_files_for_Qt6::moc "${_IMPORT_PREFIX}/lib/qt6/libexec/moc" )

# Import target "Qt6::rcc" for configuration "Release"
set_property(TARGET Qt6::rcc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::rcc PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/rcc"
  )

list(APPEND _cmake_import_check_targets Qt6::rcc )
list(APPEND _cmake_import_check_files_for_Qt6::rcc "${_IMPORT_PREFIX}/lib/qt6/libexec/rcc" )

# Import target "Qt6::tracegen" for configuration "Release"
set_property(TARGET Qt6::tracegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::tracegen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/tracegen"
  )

list(APPEND _cmake_import_check_targets Qt6::tracegen )
list(APPEND _cmake_import_check_files_for_Qt6::tracegen "${_IMPORT_PREFIX}/lib/qt6/libexec/tracegen" )

# Import target "Qt6::cmake_automoc_parser" for configuration "Release"
set_property(TARGET Qt6::cmake_automoc_parser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::cmake_automoc_parser PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/cmake_automoc_parser"
  )

list(APPEND _cmake_import_check_targets Qt6::cmake_automoc_parser )
list(APPEND _cmake_import_check_files_for_Qt6::cmake_automoc_parser "${_IMPORT_PREFIX}/lib/qt6/libexec/cmake_automoc_parser" )

# Import target "Qt6::qlalr" for configuration "Release"
set_property(TARGET Qt6::qlalr APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qlalr PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/qlalr"
  )

list(APPEND _cmake_import_check_targets Qt6::qlalr )
list(APPEND _cmake_import_check_files_for_Qt6::qlalr "${_IMPORT_PREFIX}/lib/qt6/libexec/qlalr" )

# Import target "Qt6::qtpaths" for configuration "Release"
set_property(TARGET Qt6::qtpaths APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtpaths PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qtpaths"
  )

list(APPEND _cmake_import_check_targets Qt6::qtpaths )
list(APPEND _cmake_import_check_files_for_Qt6::qtpaths "${_IMPORT_PREFIX}/lib/qt6/bin/qtpaths" )

# Import target "Qt6::androiddeployqt" for configuration "Release"
set_property(TARGET Qt6::androiddeployqt APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::androiddeployqt PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/androiddeployqt"
  )

list(APPEND _cmake_import_check_targets Qt6::androiddeployqt )
list(APPEND _cmake_import_check_files_for_Qt6::androiddeployqt "${_IMPORT_PREFIX}/lib/qt6/bin/androiddeployqt" )

# Import target "Qt6::androidtestrunner" for configuration "Release"
set_property(TARGET Qt6::androidtestrunner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::androidtestrunner PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/androidtestrunner"
  )

list(APPEND _cmake_import_check_targets Qt6::androidtestrunner )
list(APPEND _cmake_import_check_files_for_Qt6::androidtestrunner "${_IMPORT_PREFIX}/lib/qt6/bin/androidtestrunner" )

# Import target "Qt6::qmake" for configuration "Release"
set_property(TARGET Qt6::qmake APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmake PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmake"
  )

list(APPEND _cmake_import_check_targets Qt6::qmake )
list(APPEND _cmake_import_check_files_for_Qt6::qmake "${_IMPORT_PREFIX}/lib/qt6/bin/qmake" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> qt6-qtbase-6.5.2.tgz: lib/cmake/Qt6CoreTools/Qt6CoreToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::moc" for configuration "Release"
set_property(TARGET Qt6::moc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::moc PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/moc"
  )

list(APPEND _cmake_import_check_targets Qt6::moc )
list(APPEND _cmake_import_check_files_for_Qt6::moc "${_IMPORT_PREFIX}/lib/qt6/libexec/moc" )

# Import target "Qt6::rcc" for configuration "Release"
set_property(TARGET Qt6::rcc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::rcc PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/rcc"
  )

list(APPEND _cmake_import_check_targets Qt6::rcc )
list(APPEND _cmake_import_check_files_for_Qt6::rcc "${_IMPORT_PREFIX}/lib/qt6/libexec/rcc" )

# Import target "Qt6::tracepointgen" for configuration "Release"
set_property(TARGET Qt6::tracepointgen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::tracepointgen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/tracepointgen"
  )

list(APPEND _cmake_import_check_targets Qt6::tracepointgen )
list(APPEND _cmake_import_check_files_for_Qt6::tracepointgen "${_IMPORT_PREFIX}/lib/qt6/libexec/tracepointgen" )

# Import target "Qt6::tracegen" for configuration "Release"
set_property(TARGET Qt6::tracegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::tracegen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/tracegen"
  )

list(APPEND _cmake_import_check_targets Qt6::tracegen )
list(APPEND _cmake_import_check_files_for_Qt6::tracegen "${_IMPORT_PREFIX}/lib/qt6/libexec/tracegen" )

# Import target "Qt6::cmake_automoc_parser" for configuration "Release"
set_property(TARGET Qt6::cmake_automoc_parser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::cmake_automoc_parser PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/cmake_automoc_parser"
  )

list(APPEND _cmake_import_check_targets Qt6::cmake_automoc_parser )
list(APPEND _cmake_import_check_files_for_Qt6::cmake_automoc_parser "${_IMPORT_PREFIX}/lib/qt6/libexec/cmake_automoc_parser" )

# Import target "Qt6::qlalr" for configuration "Release"
set_property(TARGET Qt6::qlalr APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qlalr PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/libexec/qlalr"
  )

list(APPEND _cmake_import_check_targets Qt6::qlalr )
list(APPEND _cmake_import_check_files_for_Qt6::qlalr "${_IMPORT_PREFIX}/lib/qt6/libexec/qlalr" )

# Import target "Qt6::qtpaths" for configuration "Release"
set_property(TARGET Qt6::qtpaths APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtpaths PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qtpaths"
  )

list(APPEND _cmake_import_check_targets Qt6::qtpaths )
list(APPEND _cmake_import_check_files_for_Qt6::qtpaths "${_IMPORT_PREFIX}/lib/qt6/bin/qtpaths" )

# Import target "Qt6::androiddeployqt" for configuration "Release"
set_property(TARGET Qt6::androiddeployqt APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::androiddeployqt PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/androiddeployqt"
  )

list(APPEND _cmake_import_check_targets Qt6::androiddeployqt )
list(APPEND _cmake_import_check_files_for_Qt6::androiddeployqt "${_IMPORT_PREFIX}/lib/qt6/bin/androiddeployqt" )

# Import target "Qt6::androidtestrunner" for configuration "Release"
set_property(TARGET Qt6::androidtestrunner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::androidtestrunner PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/androidtestrunner"
  )

list(APPEND _cmake_import_check_targets Qt6::androidtestrunner )
list(APPEND _cmake_import_check_files_for_Qt6::androidtestrunner "${_IMPORT_PREFIX}/lib/qt6/bin/androidtestrunner" )

# Import target "Qt6::qmake" for configuration "Release"
set_property(TARGET Qt6::qmake APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qmake PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/qmake"
  )

list(APPEND _cmake_import_check_targets Qt6::qmake )
list(APPEND _cmake_import_check_files_for_Qt6::qmake "${_IMPORT_PREFIX}/lib/qt6/bin/qmake" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
